@@ -404,7 +404,8 @@ class WorkspaceItemAdapter(object):
         can be provided. Default layout_options:
 
         layout_options = {'add_snippet': False,
-                         'editing': False}
+                         'editing': False,
+                         'request': request}
         """
         return 'html output for this adapter is not implemented'
 
